@@ -1,41 +1,17 @@
-# Copyright (c) 2020 - 2022  Peter Pentchev <roam@ringlet.net>
-# All rights reserved.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-# 1. Redistributions of source code must retain the above copyright
-#    notice, this list of conditions and the following disclaimer.
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions and the following disclaimer in the
-#    documentation and/or other materials provided with the distribution.
-#
-# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
-# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
-# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-# SUCH DAMAGE.
+# SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
+# SPDX-License-Identifier: BSD-2-Clause
 """Test the UTF-8 locale detection functions."""
 
 from __future__ import annotations
 
+import functools
 import json
 import os
 import pathlib
 import subprocess
-import unittest
-
+from typing import Iterable, NamedTuple
 from unittest import mock
 
-from typing import Iterable, NamedTuple
-
-import ddt  # type: ignore
 import pytest
 
 import utf8_locale
@@ -55,36 +31,25 @@ class TData(NamedTuple):
     languages: list[TLangData]
 
 
-class TDataHolder:
-    """A singleton object holding the test data."""
-
-    # pylint: disable=too-few-public-methods
-
-    data: TData | None = None
-
-    @classmethod
-    def load(cls) -> TData:
-        """Load the test data from the JSON definitions file."""
-        if cls.data is not None:
-            return cls.data
-
-        raw = json.loads(
-            (pathlib.Path(__file__).absolute().parent.parent.parent / "tests/data.json").read_text(
-                encoding="UTF-8"
-            )
+@functools.lru_cache
+def load_test_data() -> TData:
+    """Load the test data from the JSON definitions file."""
+    raw = json.loads(
+        (pathlib.Path(__file__).absolute().parent.parent.parent / "tests/data.json").read_text(
+            encoding="UTF-8"
         )
-        assert raw["format"]["version"] == {"major": 0, "minor": 1}
+    )
+    assert raw["format"]["version"] == {"major": 0, "minor": 1}
 
-        cls.data = TData(
-            locales=raw["locales"],
-            languages=[
-                TLangData(env=item["env"], expected=item["expected"]) for item in raw["languages"]
-            ],
-        )
-        return cls.data
+    return TData(
+        locales=raw["locales"],
+        languages=[
+            TLangData(env=item["env"], expected=item["expected"]) for item in raw["languages"]
+        ],
+    )
 
 
-LANG_KEYS = set(["LC_ALL", "LANGUAGE"])
+LANG_KEYS = {"LC_ALL", "LANGUAGE"}
 
 LANG_EXPECTED = [
     (["C", "en"], "C.UTF-8"),
@@ -117,8 +82,8 @@ def check_env(env: dict[str, str]) -> None:
             ).splitlines()
         )
     }
-    non_lc = set(name for name in loc if not name.startswith("LC_"))
-    assert non_lc.issubset(set(("LANG", "LANGUAGE")))
+    non_lc = {name for name in loc if not name.startswith("LC_")}
+    assert non_lc.issubset({"LANG", "LANGUAGE"})
     loc = {name: value for name, value in loc.items() if name.startswith("LC_")}
     values = list(set(loc.values()))
     assert len(values) == 1, values
@@ -169,28 +134,27 @@ def test_utf8_env() -> None:
     check_mod_env(env, mod_env, env2)
 
 
-def mock_locale():  # type: ignore
+def mock_locale() -> mock._patch[mock.Mock]:  # noqa: SLF001
     """Mock subprocess.check_output("locale -a")."""
-    locales = TDataHolder.load().locales
+    locales = load_test_data().locales
     mock_check_output = mock.Mock(spec=["__call__"])
     mock_check_output.return_value = "".join(item + "\n" for item in locales)
     return mock.patch("subprocess.check_output", new=mock_check_output)
 
 
-@ddt.ddt
-class TestLanguages(unittest.TestCase):
+class TestLanguages:
     """Test the language preference handling of detect_utf8_locale()."""
 
     @staticmethod
     def detect_locale(languages: Iterable[str]) -> str:
         """Get the locale name using the appropriate mechanism."""
-        with mock_locale():  # type: ignore
+        with mock_locale():
             return utf8_locale.detect_utf8_locale(languages=languages)
 
     @staticmethod
     def get_vars(languages: Iterable[str]) -> dict[str, str]:
         """Get the variables dict using the appropriate mechanism."""
-        with mock_locale():  # type: ignore
+        with mock_locale():
             return utf8_locale.get_utf8_vars(languages=languages)
 
     @staticmethod
@@ -198,14 +162,12 @@ class TestLanguages(unittest.TestCase):
         """Get the preferred languages using the appropriate mechanism."""
         return utf8_locale.get_preferred_languages(env)
 
-    @ddt.data(*LANG_EXPECTED)
-    @ddt.unpack
+    @pytest.mark.parametrize(("languages", "result"), LANG_EXPECTED)
     def test_language(self, languages: list[str], result: str) -> None:
         """Test detect_utf8_locale() with some languages specified."""
         assert self.detect_locale(iter(languages)) == result
 
-    @ddt.data(*LANG_EXPECTED)
-    @ddt.unpack
+    @pytest.mark.parametrize(("languages", "result"), LANG_EXPECTED)
     def test_language_vars(self, languages: list[str], result: str) -> None:
         """Test detect_utf8_locale() with some languages specified."""
         assert self.get_vars(iter(languages)) == {
@@ -215,10 +177,10 @@ class TestLanguages(unittest.TestCase):
 
     def test_no_languages(self) -> None:
         """Test detect_utf8_locale() with no languages specified."""
-        with pytest.raises(ValueError):
+        with pytest.raises(utf8_locale.NoLanguagesError):
             self.detect_locale(languages=iter([]))
 
-    @ddt.data(*TDataHolder.load().languages)
+    @pytest.mark.parametrize("tcase", load_test_data().languages)
     def test_preferred(self, tcase: TLangData) -> None:
         """Test get_preferred_languages() with the specified environment."""
         assert self.get_langs(tcase.env) == tcase.expected
