@@ -1,26 +1,5 @@
-# Copyright (c) 2022  Peter Pentchev <roam@ringlet.net>
-# All rights reserved.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-# 1. Redistributions of source code must retain the above copyright
-#    notice, this list of conditions and the following disclaimer.
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions and the following disclaimer in the
-#    documentation and/or other materials provided with the distribution.
-#
-# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
-# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
-# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-# SUCH DAMAGE.
+# SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
+# SPDX-License-Identifier: BSD-2-Clause
 """The u8loc command-line tool."""
 
 from __future__ import annotations
@@ -28,8 +7,8 @@ from __future__ import annotations
 import argparse
 import dataclasses
 import os
+import subprocess
 import sys
-
 from typing import Callable, NamedTuple
 
 from . import detect
@@ -154,11 +133,11 @@ def parse_args() -> Config:
             sys.exit("No program to run specified")
         return RunConfig(preferred=args.preferred, run_program=args.program)
 
-    raise NotImplementedError(f"Did not expect to reach the end of parse_args() with {args!r}")
+    sys.exit(f"Did not expect to reach the end of parse_args() with {args!r}")
 
 
 def main() -> None:
-    """The main routine for the u8loc command-line tool."""
+    """Parse command-line arguments, dispatch commands."""
     cfg = parse_args()
 
     if isinstance(cfg, QueryConfig) and QUERY_HANDLERS[cfg.query].early:
@@ -172,21 +151,22 @@ def main() -> None:
             detect.LanguagesDetect().detect() if cfg.preferred else list(detect.UTF8_LANGUAGES)
         )
         env = detect.UTF8Detect(languages=iter(languages)).detect()
-        assert env.languages == languages, f"{env.languages!r} != {languages!r}"
-    except Exception as err:  # pylint: disable=broad-except
+        if env.languages != languages:
+            sys.exit("utf8-locale internal error: env {env.languages!r} != {languages!r}")
+    except (detect.NoLanguagesError, OSError, subprocess.CalledProcessError) as err:
         sys.exit(f"Could not determine an appropriate UTF-8 locale: {err}")
 
     if isinstance(cfg, RunConfig):
         try:
             os.execvpe(cfg.run_program[0], cfg.run_program, env.env)
-        except Exception as err:  # pylint: disable=broad-except
+        except OSError as err:
             sys.exit(f"Could not run '{' '.join(cfg.run_program)}': {err}")
 
     if isinstance(cfg, QueryConfig):
         QUERY_HANDLERS[cfg.query].handler(cfg, env)
         return
 
-    raise NotImplementedError(f"Did not expect to reach the end of main() with {cfg!r}")
+    sys.exit(f"Did not expect to reach the end of main() with {cfg!r}")
 
 
 if __name__ == "__main__":
