@@ -1,26 +1,5 @@
-# Copyright (c) 2020 - 2022  Peter Pentchev <roam@ringlet.net>
-# All rights reserved.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-# 1. Redistributions of source code must retain the above copyright
-#    notice, this list of conditions and the following disclaimer.
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions and the following disclaimer in the
-#    documentation and/or other materials provided with the distribution.
-#
-# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
-# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
-# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-# SUCH DAMAGE.
+# SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
+# SPDX-License-Identifier: BSD-2-Clause
 
 """Implement the actual UTF-8 locale detection."""
 
@@ -30,10 +9,10 @@ import dataclasses
 import os
 import re
 import subprocess
-
 from typing import Iterable, NamedTuple
 
-VERSION = "1.0.0"
+
+VERSION = "1.0.1"
 
 UTF8_LANGUAGES = ("C", "en", "de", "es", "it")
 UTF8_ENCODINGS = ("UTF-8", "utf8")
@@ -75,6 +54,14 @@ RE_LOCALE_NAME = re.compile(
 )
 
 
+class NoLanguagesError(ValueError):
+    """No languages were specified to detect from."""
+
+    def __str__(self) -> str:
+        """Provide a human-readable representation of the error."""
+        return "No languages specified"
+
+
 class _DetectState(NamedTuple):
     """The state of processing consecutive lines of `locale -a` output."""
 
@@ -111,7 +98,7 @@ def detect_utf8_locale(*, languages: Iterable[str] = UTF8_LANGUAGES) -> str:
             weights[lang] = unweight
             unweight = unweight + 1
     if not weights:
-        raise ValueError("No languages specified")
+        raise NoLanguagesError
 
     state = _DetectState(unweight, "C")
     for line in subprocess.check_output(
